@@ -20,7 +20,7 @@ def edit_today(journal_path):
     if not entry_path.is_file():
         create_entry(f"{entry_path}/{today.day}.tex")
 
-    subprocess.call([EDITOR, entry_path])
+    subprocess.call([EDITOR, entry_path/f"{today.day}.tex"])
 
 
 def create_entry(entry_path):
